import culqipy, unittest ,json, uuid

culqipy.COD_COMMERCE = "pk_test_vzMuTHoueOMlgUPj"
culqipy.API_KEY = "sk_test_UTCQSGcXW8bCyU59"

class TestStringMethods(unittest.TestCase):

    def token(self):
        token = culqipy.Token.create(
            card_number="4111111111111111",
            currency_code="PEN",
            cvv="123",
            exp_month=9,
            exp_year=2020,
            fingerprint="q352454534",
            last_name="Muro",
            email="wmuro@me.com",
            first_name="William")
        return token


    def charge(self):
        charge = culqipy.Charge.create(
            address="Avenida Lima 1232",
            address_city="LIMA",
            amount=1000,
            country_code="PE",
            currency_code="PEN",
            email="wmuro@me.com",
            first_name="William",
            installments=0,
            last_name="Muro",
            metadata="",
            phone_number=3333339,
            product_description="Venta de prueba",
            token_id=self.token()["id"])
        return charge

    def plan(self):
        plan = culqipy.Plan.create(
            alias="plan-test-"+str(uuid.uuid1()),
            amount=1000,
            currency_code="PEN",
            interval="day",
            interval_count=2,
            limit=10,
            name="Plan de Prueba "+str(uuid.uuid1()),
            trial_days=50)
        return plan

    def subscription(self):
        subscription = culqipy.Subscription.create(
            address="Avenida Lima 123213",
            address_city="LIMA",
            country_code="PE",
            email="wmuro@me.com",
            last_name="Muro",
            first_name="William",
            phone_number=1234567789,
            plan_alias=self.plan()["alias"],
            token_id=self.token()["id"])
        return subscription

    def refund(self):
        refund = culqipy.Refund.create(
            amount=500,
            charge_id=self.charge()["id"],
            reason="give me money back")
        return refund

    def test_token(self):
        self.assertEqual("token", str(self.token()["object"]))

    def test_charge(self):
        self.assertEqual("charge", str(self.charge()["object"]))

    def test_plan(self):
        self.assertEqual("plan", str(self.plan()["object"]))

    def test_subscription(self):
        self.assertEqual("subscription", str(self.subscription()["object"]))

    def test_refund(self):
        self.assertEqual("refund", str(self.refund()["object"]))

if __name__ == '__main__':
    unittest.main()



import culqipy, json, util
from object import Object

class Charge:

    def create(self, address, address_city, amount, country_code, currency_code, email, first_name, installments, last_name,
                     metadata, phone_number, product_description, token_id):
        charge = Object()
        charge.address = address
        charge.address_city = address_city
        charge.amount = amount
        charge.country_code = country_code
        charge.currency_code = currency_code
        charge.email = email
        charge.first_name = first_name
        charge.installments = installments
        charge.last_name = last_name
        charge.metadata = metadata
        charge.phone_number = phone_number
        charge.product_description = product_description
        charge.token_id = token_id
        return util.jsonResult(culqipy.API_KEY, "/charges/", charge.toJSON(), "POST")



import culqipy, json, util
from object import Object

class Subscription:

    def create(self, address, address_city, country_code, email, last_name, first_name, phone_number, plan_alias, token_id):
        subscription = Object()
        subscription.address = address
        subscription.address_city = address_city
        subscription.country_code = country_code
        subscription.email = email
        subscription.last_name = last_name
        subscription.first_name = first_name
        subscription.phone_number = phone_number
        subscription.plan_alias = plan_alias
        subscription.token_id = token_id
        return util.jsonResult(culqipy.API_KEY, "/subscriptions/", subscription.toJSON(), "POST")



import culqipy, json, util
from object import Object

class Refund:

    def create(self, amount, charge_id, reason):
        refund = Object()
        refund.amount = amount
        refund.charge_id = charge_id
        refund.reason = reason
        return util.jsonResult(culqipy.API_KEY, "/refunds/", refund.toJSON(), "POST")



import culqipy, json, util
from object import Object

class Plan:

    def create(self, alias, amount, currency_code, interval, interval_count, limit, name, trial_days):
        plan = Object()
        plan.alias = alias
        plan.amount = amount
        plan.currency_code = currency_code
        plan.interval = interval
        plan.interval_count = interval_count
        plan.limit = limit
        plan.name = name
        plan.trial_days = trial_days
        return util.jsonResult(culqipy.API_KEY, "/plans/", plan.toJSON(), "POST")



import culqipy, requests, json
from object import Object

class Token:

    def create(self, card_number, currency_code, cvv, exp_month, exp_year, fingerprint, last_name, email, first_name):
        token = Object()
        token.card_number = card_number
        token.currency_code = currency_code
        token.cvv = cvv
        token.expiration_month = exp_month
        token.expiration_year = exp_year
        token.fingerprint = fingerprint
        token.last_name = last_name
        token.email = email
        token.first_name = first_name
        headers = {"Authorization": "Code "+culqipy.COD_COMMERCE, "content-type": "application/json"}
        r = requests.post(culqipy.API_URL+"/tokens/", headers=headers, data=token.toJSON(), timeout=60)
        return r.json()



# Configuration variables

API_URL = "https://api.culqi.com/v2"
COD_COMMERCE = None
API_KEY = None

# Resource

from culqipy import *

Token = token.Token()
Charge = charge.Charge()
Plan = plan.Plan()
Subscription = subscription.Subscription()
Refund = refund.Refund()



from distutils.core import setup
setup(
  name = 'culqipy',
  packages = ['culqipy'],
  version = '0.1.4',
  description = 'Biblioteca de Culqi en Python',
  author = 'Willy Aguirre - Culqi Team',
  author_email = 'willy.aguirre@culqi.com',
  url = 'https://github.com/culqi/culqi-python',
  download_url = 'https://github.com/culqi/culqi-python/tarball/0.1.3',
  keywords = ['api', 'json', 'culqi', 'apiv2'],
  classifiers = [],
)



import culqipy, requests

def jsonResult(key, url, data, method):
    headers = {"Authorization": "Bearer "+key, "content-type": "application/json"}
    r = ""
    if method.upper() == "POST":
        r = requests.post(culqipy.API_URL+url, headers=headers, data=data, timeout=60)
    return r.json()
